pub(super) struct ExtraDeviceData {
media_type: MediaType,
viewport_size: Size2D<f32, CSSPixel>,
device_pixel_ratio: Scale<f32, CSSPixel, DevicePixel>,
quirks_mode: QuirksMode,
prefers_color_scheme: PrefersColorScheme,
font_metrics_provider: Box<dyn FontMetricsProvider>,
}Fields
media_type: MediaTypeThe current media type used by de device.
viewport_size: Size2D<f32, CSSPixel>The current viewport size, in CSS pixels.
device_pixel_ratio: Scale<f32, CSSPixel, DevicePixel>The current device pixel ratio, from CSS pixels to device pixels.
quirks_mode: QuirksModeThe current quirks mode.
prefers_color_scheme: PrefersColorSchemeWhether the user prefers light mode or dark mode
font_metrics_provider: Box<dyn FontMetricsProvider>An implementation of a trait which implements support for querying font metrics.